@@ -1,9 +1,9 @@
 lib_dir = File.expand_path(File.join(File.dirname(__FILE__), '../../lib'))
 
-if File.exists?(File.join(lib_dir, 'daemons.rb'))
+if File.exist?(File.join(lib_dir, 'daemons.rb'))
   $LOAD_PATH.unshift lib_dir
 else
-  require 'rubygems' rescue nil
+  begin; require 'rubygems'; rescue ::Exception; end
 end
 
 require 'daemons'
